QRCode encoder
This crate provides a QR code, Micro QR and rMQR code encoder for binary data.
use qrqrpar::{QrCode, QrStyle};
// Encode some data into bits.
let code = QrCode::rmqr("Hello, rmqr!").unwrap();
// Define style
let style = QrStyle::default();
// Render the bits into an image and save it.
code.save_png("rmqr.png", &style).unwrap();Re-exports
pub use crate::bits::RmqrStrategy;pub use crate::types::Color;pub use crate::types::EcLevel;pub use crate::types::QrResult;pub use crate::types::Version;
Modules
- bits
- The
bitsmodule encodes binary data into raw bits used in a QR code. - canvas
- The
canvasmodule puts raw bits into the QR code canvas. - coding
- Find the optimal data mode sequence to encode a piece of data.
- ec
- The
ecmodule applies the Reed-Solomon error correction codes. - types